def sing():
    print("Bibi, bibi, bibi Cammello\n"\
          "Aveva una gobba proprio come un Cammello\n"\
          "Bibi, bibi, bibi Cammello\n"\
          "Andava sempre in giro con il suo ombrello\n"
          )



