"""  Created on 09/06/2023::
------------- __about__.py -------------

**Authors**: L. Mingarelli
"""

__about__ = "A singing Cammello."
__version__= '0.0.1'
__author__ = 'Luca Mingarelli'
__email__ = "lucamingarelli@me.com"
__url__ = "https://github.com/LucaMingarelli/cammello"
